# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.board_ticket_statuses_api import BoardTicketStatusesApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestBoardTicketStatusesApi(unittest.TestCase):
    """BoardTicketStatusesApi unit test stubs"""

    def setUp(self):
        self.api = BoardTicketStatusesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_status(self):
        """Test case for create_status

        Creates a status  # noqa: E501
        """
        pass

    def test_delete_status(self):
        """Test case for delete_status

        Deletes the Status with the specified id.  # noqa: E501
        """
        pass

    def test_get_default_statuses(self):
        """Test case for get_default_statuses

        Gets a list of the default statuses in arbitrary,  static order.    The ids specified on these StatusChildren are to allow easy differentiation on  the frontend. They do not represent anything stored in the db.  # noqa: E501
        """
        pass

    def test_get_status(self):
        """Test case for get_status

        Gets a Status  # noqa: E501
        """
        pass

    def test_update_status(self):
        """Test case for update_status

        Updates the status with the specified id  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.tags_api import TagsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestTagsApi(unittest.TestCase):
    """TagsApi unit test stubs"""

    def setUp(self):
        self.api = TagsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_tag(self):
        """Test case for create_tag

        Creates a tag  # noqa: E501
        """
        pass

    def test_get_tag(self):
        """Test case for get_tag

        Gets a tag  # noqa: E501
        """
        pass

    def test_get_tags(self):
        """Test case for get_tags

        Gets tags  # noqa: E501
        """
        pass

    def test_update_tag(self):
        """Test case for update_tag

        Updates a tag  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class IndicatorResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'abbreviation': 'str',
        'system_sort_order': 'int',
        'indicator_type': 'MetricTypeCodes',
        'measure_of': 'SensorRoleTypeCodes',
        'custom_role_type': 'str',
        'display_units': 'str',
        'base_units': 'str',
        'has_spectrum': 'bool',
        'meta_data': 'str',
        'damage_exponent': 'int',
        'location': 'LocationChild',
        'hierarchy': 'list[HierarchyChild]',
        'alarm_definition': 'AlarmDefinitionChild',
        'band_definition': 'BandDefinitionChild',
        'baseline': 'BaselineIndicatorChild',
        'can_have_baseline': 'bool',
        'is_vibration': 'bool',
        'custom_units': 'str',
        'tags': 'list[str]'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'abbreviation': 'Abbreviation',
        'system_sort_order': 'SystemSortOrder',
        'indicator_type': 'IndicatorType',
        'measure_of': 'MeasureOf',
        'custom_role_type': 'CustomRoleType',
        'display_units': 'DisplayUnits',
        'base_units': 'BaseUnits',
        'has_spectrum': 'HasSpectrum',
        'meta_data': 'MetaData',
        'damage_exponent': 'DamageExponent',
        'location': 'Location',
        'hierarchy': 'Hierarchy',
        'alarm_definition': 'AlarmDefinition',
        'band_definition': 'BandDefinition',
        'baseline': 'Baseline',
        'can_have_baseline': 'CanHaveBaseline',
        'is_vibration': 'IsVibration',
        'custom_units': 'CustomUnits',
        'tags': 'Tags'
    }

    def __init__(self, id=None, name=None, abbreviation=None, system_sort_order=None, indicator_type=None, measure_of=None, custom_role_type=None, display_units=None, base_units=None, has_spectrum=None, meta_data=None, damage_exponent=None, location=None, hierarchy=None, alarm_definition=None, band_definition=None, baseline=None, can_have_baseline=None, is_vibration=None, custom_units=None, tags=None):  # noqa: E501
        """IndicatorResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._abbreviation = None
        self._system_sort_order = None
        self._indicator_type = None
        self._measure_of = None
        self._custom_role_type = None
        self._display_units = None
        self._base_units = None
        self._has_spectrum = None
        self._meta_data = None
        self._damage_exponent = None
        self._location = None
        self._hierarchy = None
        self._alarm_definition = None
        self._band_definition = None
        self._baseline = None
        self._can_have_baseline = None
        self._is_vibration = None
        self._custom_units = None
        self._tags = None
        self.discriminator = None
        self.id = id
        self.name = name
        if abbreviation is not None:
            self.abbreviation = abbreviation
        self.system_sort_order = system_sort_order
        self.indicator_type = indicator_type
        self.measure_of = measure_of
        if custom_role_type is not None:
            self.custom_role_type = custom_role_type
        if display_units is not None:
            self.display_units = display_units
        if base_units is not None:
            self.base_units = base_units
        self.has_spectrum = has_spectrum
        if meta_data is not None:
            self.meta_data = meta_data
        if damage_exponent is not None:
            self.damage_exponent = damage_exponent
        self.location = location
        self.hierarchy = hierarchy
        if alarm_definition is not None:
            self.alarm_definition = alarm_definition
        if band_definition is not None:
            self.band_definition = band_definition
        if baseline is not None:
            self.baseline = baseline
        self.can_have_baseline = can_have_baseline
        self.is_vibration = is_vibration
        if custom_units is not None:
            self.custom_units = custom_units
        self.tags = tags

    @property
    def id(self):
        """Gets the id of this IndicatorResponse.  # noqa: E501

        The Id of the indicator  # noqa: E501

        :return: The id of this IndicatorResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this IndicatorResponse.

        The Id of the indicator  # noqa: E501

        :param id: The id of this IndicatorResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this IndicatorResponse.  # noqa: E501

        The name of the indicator  # noqa: E501

        :return: The name of this IndicatorResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IndicatorResponse.

        The name of the indicator  # noqa: E501

        :param name: The name of this IndicatorResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def abbreviation(self):
        """Gets the abbreviation of this IndicatorResponse.  # noqa: E501

        The abbreviation of the indicator  # noqa: E501

        :return: The abbreviation of this IndicatorResponse.  # noqa: E501
        :rtype: str
        """
        return self._abbreviation

    @abbreviation.setter
    def abbreviation(self, abbreviation):
        """Sets the abbreviation of this IndicatorResponse.

        The abbreviation of the indicator  # noqa: E501

        :param abbreviation: The abbreviation of this IndicatorResponse.  # noqa: E501
        :type: str
        """

        self._abbreviation = abbreviation

    @property
    def system_sort_order(self):
        """Gets the system_sort_order of this IndicatorResponse.  # noqa: E501

        A number indicating where the indicator shows up in the list of indicators for a System.  # noqa: E501

        :return: The system_sort_order of this IndicatorResponse.  # noqa: E501
        :rtype: int
        """
        return self._system_sort_order

    @system_sort_order.setter
    def system_sort_order(self, system_sort_order):
        """Sets the system_sort_order of this IndicatorResponse.

        A number indicating where the indicator shows up in the list of indicators for a System.  # noqa: E501

        :param system_sort_order: The system_sort_order of this IndicatorResponse.  # noqa: E501
        :type: int
        """
        if system_sort_order is None:
            raise ValueError("Invalid value for `system_sort_order`, must not be `None`")  # noqa: E501

        self._system_sort_order = system_sort_order

    @property
    def indicator_type(self):
        """Gets the indicator_type of this IndicatorResponse.  # noqa: E501


        :return: The indicator_type of this IndicatorResponse.  # noqa: E501
        :rtype: MetricTypeCodes
        """
        return self._indicator_type

    @indicator_type.setter
    def indicator_type(self, indicator_type):
        """Sets the indicator_type of this IndicatorResponse.


        :param indicator_type: The indicator_type of this IndicatorResponse.  # noqa: E501
        :type: MetricTypeCodes
        """
        if indicator_type is None:
            raise ValueError("Invalid value for `indicator_type`, must not be `None`")  # noqa: E501

        self._indicator_type = indicator_type

    @property
    def measure_of(self):
        """Gets the measure_of of this IndicatorResponse.  # noqa: E501


        :return: The measure_of of this IndicatorResponse.  # noqa: E501
        :rtype: SensorRoleTypeCodes
        """
        return self._measure_of

    @measure_of.setter
    def measure_of(self, measure_of):
        """Sets the measure_of of this IndicatorResponse.


        :param measure_of: The measure_of of this IndicatorResponse.  # noqa: E501
        :type: SensorRoleTypeCodes
        """
        if measure_of is None:
            raise ValueError("Invalid value for `measure_of`, must not be `None`")  # noqa: E501

        self._measure_of = measure_of

    @property
    def custom_role_type(self):
        """Gets the custom_role_type of this IndicatorResponse.  # noqa: E501

        For indicators with MeasureOf == Custom, the virtual \"sensor\" they read data from  # noqa: E501

        :return: The custom_role_type of this IndicatorResponse.  # noqa: E501
        :rtype: str
        """
        return self._custom_role_type

    @custom_role_type.setter
    def custom_role_type(self, custom_role_type):
        """Sets the custom_role_type of this IndicatorResponse.

        For indicators with MeasureOf == Custom, the virtual \"sensor\" they read data from  # noqa: E501

        :param custom_role_type: The custom_role_type of this IndicatorResponse.  # noqa: E501
        :type: str
        """

        self._custom_role_type = custom_role_type

    @property
    def display_units(self):
        """Gets the display_units of this IndicatorResponse.  # noqa: E501

        The short hand form of the `BaseUnit` used for the display (g, °C, mm/sec)  # noqa: E501

        :return: The display_units of this IndicatorResponse.  # noqa: E501
        :rtype: str
        """
        return self._display_units

    @display_units.setter
    def display_units(self, display_units):
        """Sets the display_units of this IndicatorResponse.

        The short hand form of the `BaseUnit` used for the display (g, °C, mm/sec)  # noqa: E501

        :param display_units: The display_units of this IndicatorResponse.  # noqa: E501
        :type: str
        """

        self._display_units = display_units

    @property
    def base_units(self):
        """Gets the base_units of this IndicatorResponse.  # noqa: E501

        The full name of the Unit (G-Force, Celsius, MillimetersperSec)  # noqa: E501

        :return: The base_units of this IndicatorResponse.  # noqa: E501
        :rtype: str
        """
        return self._base_units

    @base_units.setter
    def base_units(self, base_units):
        """Sets the base_units of this IndicatorResponse.

        The full name of the Unit (G-Force, Celsius, MillimetersperSec)  # noqa: E501

        :param base_units: The base_units of this IndicatorResponse.  # noqa: E501
        :type: str
        """

        self._base_units = base_units

    @property
    def has_spectrum(self):
        """Gets the has_spectrum of this IndicatorResponse.  # noqa: E501

        Whether or not the indicator produces burst data that can be plotted  on a spectrum chart (the frequency or time wave spectrum's)  # noqa: E501

        :return: The has_spectrum of this IndicatorResponse.  # noqa: E501
        :rtype: bool
        """
        return self._has_spectrum

    @has_spectrum.setter
    def has_spectrum(self, has_spectrum):
        """Sets the has_spectrum of this IndicatorResponse.

        Whether or not the indicator produces burst data that can be plotted  on a spectrum chart (the frequency or time wave spectrum's)  # noqa: E501

        :param has_spectrum: The has_spectrum of this IndicatorResponse.  # noqa: E501
        :type: bool
        """
        if has_spectrum is None:
            raise ValueError("Invalid value for `has_spectrum`, must not be `None`")  # noqa: E501

        self._has_spectrum = has_spectrum

    @property
    def meta_data(self):
        """Gets the meta_data of this IndicatorResponse.  # noqa: E501


        :return: The meta_data of this IndicatorResponse.  # noqa: E501
        :rtype: str
        """
        return self._meta_data

    @meta_data.setter
    def meta_data(self, meta_data):
        """Sets the meta_data of this IndicatorResponse.


        :param meta_data: The meta_data of this IndicatorResponse.  # noqa: E501
        :type: str
        """

        self._meta_data = meta_data

    @property
    def damage_exponent(self):
        """Gets the damage_exponent of this IndicatorResponse.  # noqa: E501


        :return: The damage_exponent of this IndicatorResponse.  # noqa: E501
        :rtype: int
        """
        return self._damage_exponent

    @damage_exponent.setter
    def damage_exponent(self, damage_exponent):
        """Sets the damage_exponent of this IndicatorResponse.


        :param damage_exponent: The damage_exponent of this IndicatorResponse.  # noqa: E501
        :type: int
        """

        self._damage_exponent = damage_exponent

    @property
    def location(self):
        """Gets the location of this IndicatorResponse.  # noqa: E501


        :return: The location of this IndicatorResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this IndicatorResponse.


        :param location: The location of this IndicatorResponse.  # noqa: E501
        :type: LocationChild
        """
        if location is None:
            raise ValueError("Invalid value for `location`, must not be `None`")  # noqa: E501

        self._location = location

    @property
    def hierarchy(self):
        """Gets the hierarchy of this IndicatorResponse.  # noqa: E501


        :return: The hierarchy of this IndicatorResponse.  # noqa: E501
        :rtype: list[HierarchyChild]
        """
        return self._hierarchy

    @hierarchy.setter
    def hierarchy(self, hierarchy):
        """Sets the hierarchy of this IndicatorResponse.


        :param hierarchy: The hierarchy of this IndicatorResponse.  # noqa: E501
        :type: list[HierarchyChild]
        """
        if hierarchy is None:
            raise ValueError("Invalid value for `hierarchy`, must not be `None`")  # noqa: E501

        self._hierarchy = hierarchy

    @property
    def alarm_definition(self):
        """Gets the alarm_definition of this IndicatorResponse.  # noqa: E501


        :return: The alarm_definition of this IndicatorResponse.  # noqa: E501
        :rtype: AlarmDefinitionChild
        """
        return self._alarm_definition

    @alarm_definition.setter
    def alarm_definition(self, alarm_definition):
        """Sets the alarm_definition of this IndicatorResponse.


        :param alarm_definition: The alarm_definition of this IndicatorResponse.  # noqa: E501
        :type: AlarmDefinitionChild
        """

        self._alarm_definition = alarm_definition

    @property
    def band_definition(self):
        """Gets the band_definition of this IndicatorResponse.  # noqa: E501


        :return: The band_definition of this IndicatorResponse.  # noqa: E501
        :rtype: BandDefinitionChild
        """
        return self._band_definition

    @band_definition.setter
    def band_definition(self, band_definition):
        """Sets the band_definition of this IndicatorResponse.


        :param band_definition: The band_definition of this IndicatorResponse.  # noqa: E501
        :type: BandDefinitionChild
        """

        self._band_definition = band_definition

    @property
    def baseline(self):
        """Gets the baseline of this IndicatorResponse.  # noqa: E501


        :return: The baseline of this IndicatorResponse.  # noqa: E501
        :rtype: BaselineIndicatorChild
        """
        return self._baseline

    @baseline.setter
    def baseline(self, baseline):
        """Sets the baseline of this IndicatorResponse.


        :param baseline: The baseline of this IndicatorResponse.  # noqa: E501
        :type: BaselineIndicatorChild
        """

        self._baseline = baseline

    @property
    def can_have_baseline(self):
        """Gets the can_have_baseline of this IndicatorResponse.  # noqa: E501

        Determines whether or not an indicator can have a baseline.  Only vibration and damage type indicators can have a baseline  # noqa: E501

        :return: The can_have_baseline of this IndicatorResponse.  # noqa: E501
        :rtype: bool
        """
        return self._can_have_baseline

    @can_have_baseline.setter
    def can_have_baseline(self, can_have_baseline):
        """Sets the can_have_baseline of this IndicatorResponse.

        Determines whether or not an indicator can have a baseline.  Only vibration and damage type indicators can have a baseline  # noqa: E501

        :param can_have_baseline: The can_have_baseline of this IndicatorResponse.  # noqa: E501
        :type: bool
        """
        if can_have_baseline is None:
            raise ValueError("Invalid value for `can_have_baseline`, must not be `None`")  # noqa: E501

        self._can_have_baseline = can_have_baseline

    @property
    def is_vibration(self):
        """Gets the is_vibration of this IndicatorResponse.  # noqa: E501

        Determines whether or not an indicator measures vibration.  Note: DamageAccumulationAccel is considered vibration.  # noqa: E501

        :return: The is_vibration of this IndicatorResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_vibration

    @is_vibration.setter
    def is_vibration(self, is_vibration):
        """Sets the is_vibration of this IndicatorResponse.

        Determines whether or not an indicator measures vibration.  Note: DamageAccumulationAccel is considered vibration.  # noqa: E501

        :param is_vibration: The is_vibration of this IndicatorResponse.  # noqa: E501
        :type: bool
        """
        if is_vibration is None:
            raise ValueError("Invalid value for `is_vibration`, must not be `None`")  # noqa: E501

        self._is_vibration = is_vibration

    @property
    def custom_units(self):
        """Gets the custom_units of this IndicatorResponse.  # noqa: E501

        This property is populated for indicators like General Input that can have custom units  assigned. The `CustomUnits` is used as the display unit when present.  # noqa: E501

        :return: The custom_units of this IndicatorResponse.  # noqa: E501
        :rtype: str
        """
        return self._custom_units

    @custom_units.setter
    def custom_units(self, custom_units):
        """Sets the custom_units of this IndicatorResponse.

        This property is populated for indicators like General Input that can have custom units  assigned. The `CustomUnits` is used as the display unit when present.  # noqa: E501

        :param custom_units: The custom_units of this IndicatorResponse.  # noqa: E501
        :type: str
        """

        self._custom_units = custom_units

    @property
    def tags(self):
        """Gets the tags of this IndicatorResponse.  # noqa: E501

        Tags associated with the indicator.  # noqa: E501

        :return: The tags of this IndicatorResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this IndicatorResponse.

        Tags associated with the indicator.  # noqa: E501

        :param tags: The tags of this IndicatorResponse.  # noqa: E501
        :type: list[str]
        """
        if tags is None:
            raise ValueError("Invalid value for `tags`, must not be `None`")  # noqa: E501

        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IndicatorResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IndicatorResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.groups_api import GroupsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestGroupsApi(unittest.TestCase):
    """GroupsApi unit test stubs"""

    def setUp(self):
        self.api = GroupsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_analytics_model_to_group(self):
        """Test case for add_analytics_model_to_group

        Add Analytics Models to a Group  # noqa: E501
        """
        pass

    def test_delete_analytics_model_from_group(self):
        """Test case for delete_analytics_model_from_group

        Deletes an Analytics Model from group  # noqa: E501
        """
        pass

    def test_get_bearings_for_group(self):
        """Test case for get_bearings_for_group

        Gets all bearings for a group  # noqa: E501
        """
        pass

    def test_get_group_alerts(self):
        """Test case for get_group_alerts

        Please use ​GET /api​/v3.0​/Alerts  Gets the alerts for the given group  # noqa: E501
        """
        pass

    def test_get_group_analytics_model(self):
        """Test case for get_group_analytics_model

        Gets a Group Analytics Model  # noqa: E501
        """
        pass

    def test_get_group_analytics_models(self):
        """Test case for get_group_analytics_models

        Gets Analytics Models assigned to a group  # noqa: E501
        """
        pass

    def test_get_group_analytics_models_for_group(self):
        """Test case for get_group_analytics_models_for_group

        Gets Analytics Models assigned to a specific group  # noqa: E501
        """
        pass

    def test_update_analytics_model_on_group(self):
        """Test case for update_analytics_model_on_group

        Updates Analytics Models for a Group  # noqa: E501
        """
        pass

    def test_update_bearings_for_group(self):
        """Test case for update_bearings_for_group

        Updates bearings for a group  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.thermal_cameras_api import ThermalCamerasApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestThermalCamerasApi(unittest.TestCase):
    """ThermalCamerasApi unit test stubs"""

    def setUp(self):
        self.api = ThermalCamerasApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_thermal_camera(self):
        """Test case for create_thermal_camera

        Create ThermalCamera object with associated ThermalCameraSettings  # noqa: E501
        """
        pass

    def test_create_thermal_camera_region(self):
        """Test case for create_thermal_camera_region

        Creates a Thermal Camera Region  # noqa: E501
        """
        pass

    def test_delete_thermal_camera(self):
        """Test case for delete_thermal_camera

        Deletes a ThermalCamera object and it's associated objects:  Regions, Images, Settings  # noqa: E501
        """
        pass

    def test_delete_thermal_camera_region(self):
        """Test case for delete_thermal_camera_region

        Deletes a Thermal Camera Region  # noqa: E501
        """
        pass

    def test_get_image(self):
        """Test case for get_image

        Gets a single thermal camera image  # noqa: E501
        """
        pass

    def test_get_latest_image(self):
        """Test case for get_latest_image

        Gets the latest ThermalCameraImage for a ThermalCamera  # noqa: E501
        """
        pass

    def test_get_thermal_camera(self):
        """Test case for get_thermal_camera

        Get a single ThermalCamera object  # noqa: E501
        """
        pass

    def test_get_thermal_camera_region(self):
        """Test case for get_thermal_camera_region

        Gets a single Thermal Camera Region  # noqa: E501
        """
        pass

    def test_get_thermal_camera_regions(self):
        """Test case for get_thermal_camera_regions

        Gets Thermal Camera Regions  # noqa: E501
        """
        pass

    def test_get_thermal_cameras(self):
        """Test case for get_thermal_cameras

        Get multiple ThermalCamera objects  # noqa: E501
        """
        pass

    def test_update_thermal_camera(self):
        """Test case for update_thermal_camera

        Updates a single Thermal Camera/ settings  # noqa: E501
        """
        pass

    def test_update_thermal_camera_region(self):
        """Test case for update_thermal_camera_region

        Updates a single Thermal Camera Region  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AssetResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'supplier': 'str',
        'manufacturer': 'str',
        'model_name': 'str',
        'location_notes': 'str',
        'notes': 'str',
        'metadata': 'str',
        'is_operator_view': 'bool',
        'type': 'AssetTypeChild',
        'category': 'AssetCategoryChild',
        'size': 'AssetSizeChild',
        'economics': 'AssetEconomicsChild',
        'running_speed': 'AssetRunningSpeedChild',
        'criticality': 'AssetCriticalityChild',
        'drum_roll': 'AssetDrumRollChild',
        'hierarchy': 'list[HierarchyChild]',
        'parent': 'ParentChild',
        'children': 'list[DescendantChild]',
        'tags': 'list[AssetTagChild]',
        'analytics_models': 'list[AssetAnalyticsModelChild]',
        'id': 'str',
        'name': 'str',
        'abbreviation': 'str',
        'active': 'bool',
        'is_paused': 'bool',
        'is_snoozed': 'bool',
        'created': 'datetime',
        'corporation': 'CorporationChild',
        'location': 'LocationChild'
    }

    attribute_map = {
        'supplier': 'Supplier',
        'manufacturer': 'Manufacturer',
        'model_name': 'ModelName',
        'location_notes': 'LocationNotes',
        'notes': 'Notes',
        'metadata': 'Metadata',
        'is_operator_view': 'IsOperatorView',
        'type': 'Type',
        'category': 'Category',
        'size': 'Size',
        'economics': 'Economics',
        'running_speed': 'RunningSpeed',
        'criticality': 'Criticality',
        'drum_roll': 'DrumRoll',
        'hierarchy': 'Hierarchy',
        'parent': 'Parent',
        'children': 'Children',
        'tags': 'Tags',
        'analytics_models': 'AnalyticsModels',
        'id': 'Id',
        'name': 'Name',
        'abbreviation': 'Abbreviation',
        'active': 'Active',
        'is_paused': 'IsPaused',
        'is_snoozed': 'IsSnoozed',
        'created': 'Created',
        'corporation': 'Corporation',
        'location': 'Location'
    }

    def __init__(self, supplier=None, manufacturer=None, model_name=None, location_notes=None, notes=None, metadata=None, is_operator_view=None, type=None, category=None, size=None, economics=None, running_speed=None, criticality=None, drum_roll=None, hierarchy=None, parent=None, children=None, tags=None, analytics_models=None, id=None, name=None, abbreviation=None, active=None, is_paused=None, is_snoozed=None, created=None, corporation=None, location=None):  # noqa: E501
        """AssetResponse - a model defined in Swagger"""  # noqa: E501
        self._supplier = None
        self._manufacturer = None
        self._model_name = None
        self._location_notes = None
        self._notes = None
        self._metadata = None
        self._is_operator_view = None
        self._type = None
        self._category = None
        self._size = None
        self._economics = None
        self._running_speed = None
        self._criticality = None
        self._drum_roll = None
        self._hierarchy = None
        self._parent = None
        self._children = None
        self._tags = None
        self._analytics_models = None
        self._id = None
        self._name = None
        self._abbreviation = None
        self._active = None
        self._is_paused = None
        self._is_snoozed = None
        self._created = None
        self._corporation = None
        self._location = None
        self.discriminator = None
        if supplier is not None:
            self.supplier = supplier
        if manufacturer is not None:
            self.manufacturer = manufacturer
        if model_name is not None:
            self.model_name = model_name
        if location_notes is not None:
            self.location_notes = location_notes
        if notes is not None:
            self.notes = notes
        if metadata is not None:
            self.metadata = metadata
        self.is_operator_view = is_operator_view
        if type is not None:
            self.type = type
        if category is not None:
            self.category = category
        if size is not None:
            self.size = size
        if economics is not None:
            self.economics = economics
        if running_speed is not None:
            self.running_speed = running_speed
        if criticality is not None:
            self.criticality = criticality
        if drum_roll is not None:
            self.drum_roll = drum_roll
        self.hierarchy = hierarchy
        self.parent = parent
        self.children = children
        self.tags = tags
        self.analytics_models = analytics_models
        self.id = id
        self.name = name
        self.abbreviation = abbreviation
        self.active = active
        self.is_paused = is_paused
        self.is_snoozed = is_snoozed
        self.created = created
        self.corporation = corporation
        self.location = location

    @property
    def supplier(self):
        """Gets the supplier of this AssetResponse.  # noqa: E501


        :return: The supplier of this AssetResponse.  # noqa: E501
        :rtype: str
        """
        return self._supplier

    @supplier.setter
    def supplier(self, supplier):
        """Sets the supplier of this AssetResponse.


        :param supplier: The supplier of this AssetResponse.  # noqa: E501
        :type: str
        """

        self._supplier = supplier

    @property
    def manufacturer(self):
        """Gets the manufacturer of this AssetResponse.  # noqa: E501


        :return: The manufacturer of this AssetResponse.  # noqa: E501
        :rtype: str
        """
        return self._manufacturer

    @manufacturer.setter
    def manufacturer(self, manufacturer):
        """Sets the manufacturer of this AssetResponse.


        :param manufacturer: The manufacturer of this AssetResponse.  # noqa: E501
        :type: str
        """

        self._manufacturer = manufacturer

    @property
    def model_name(self):
        """Gets the model_name of this AssetResponse.  # noqa: E501


        :return: The model_name of this AssetResponse.  # noqa: E501
        :rtype: str
        """
        return self._model_name

    @model_name.setter
    def model_name(self, model_name):
        """Sets the model_name of this AssetResponse.


        :param model_name: The model_name of this AssetResponse.  # noqa: E501
        :type: str
        """

        self._model_name = model_name

    @property
    def location_notes(self):
        """Gets the location_notes of this AssetResponse.  # noqa: E501


        :return: The location_notes of this AssetResponse.  # noqa: E501
        :rtype: str
        """
        return self._location_notes

    @location_notes.setter
    def location_notes(self, location_notes):
        """Sets the location_notes of this AssetResponse.


        :param location_notes: The location_notes of this AssetResponse.  # noqa: E501
        :type: str
        """

        self._location_notes = location_notes

    @property
    def notes(self):
        """Gets the notes of this AssetResponse.  # noqa: E501


        :return: The notes of this AssetResponse.  # noqa: E501
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """Sets the notes of this AssetResponse.


        :param notes: The notes of this AssetResponse.  # noqa: E501
        :type: str
        """

        self._notes = notes

    @property
    def metadata(self):
        """Gets the metadata of this AssetResponse.  # noqa: E501


        :return: The metadata of this AssetResponse.  # noqa: E501
        :rtype: str
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this AssetResponse.


        :param metadata: The metadata of this AssetResponse.  # noqa: E501
        :type: str
        """

        self._metadata = metadata

    @property
    def is_operator_view(self):
        """Gets the is_operator_view of this AssetResponse.  # noqa: E501


        :return: The is_operator_view of this AssetResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_operator_view

    @is_operator_view.setter
    def is_operator_view(self, is_operator_view):
        """Sets the is_operator_view of this AssetResponse.


        :param is_operator_view: The is_operator_view of this AssetResponse.  # noqa: E501
        :type: bool
        """
        if is_operator_view is None:
            raise ValueError("Invalid value for `is_operator_view`, must not be `None`")  # noqa: E501

        self._is_operator_view = is_operator_view

    @property
    def type(self):
        """Gets the type of this AssetResponse.  # noqa: E501


        :return: The type of this AssetResponse.  # noqa: E501
        :rtype: AssetTypeChild
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this AssetResponse.


        :param type: The type of this AssetResponse.  # noqa: E501
        :type: AssetTypeChild
        """

        self._type = type

    @property
    def category(self):
        """Gets the category of this AssetResponse.  # noqa: E501


        :return: The category of this AssetResponse.  # noqa: E501
        :rtype: AssetCategoryChild
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this AssetResponse.


        :param category: The category of this AssetResponse.  # noqa: E501
        :type: AssetCategoryChild
        """

        self._category = category

    @property
    def size(self):
        """Gets the size of this AssetResponse.  # noqa: E501


        :return: The size of this AssetResponse.  # noqa: E501
        :rtype: AssetSizeChild
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this AssetResponse.


        :param size: The size of this AssetResponse.  # noqa: E501
        :type: AssetSizeChild
        """

        self._size = size

    @property
    def economics(self):
        """Gets the economics of this AssetResponse.  # noqa: E501


        :return: The economics of this AssetResponse.  # noqa: E501
        :rtype: AssetEconomicsChild
        """
        return self._economics

    @economics.setter
    def economics(self, economics):
        """Sets the economics of this AssetResponse.


        :param economics: The economics of this AssetResponse.  # noqa: E501
        :type: AssetEconomicsChild
        """

        self._economics = economics

    @property
    def running_speed(self):
        """Gets the running_speed of this AssetResponse.  # noqa: E501


        :return: The running_speed of this AssetResponse.  # noqa: E501
        :rtype: AssetRunningSpeedChild
        """
        return self._running_speed

    @running_speed.setter
    def running_speed(self, running_speed):
        """Sets the running_speed of this AssetResponse.


        :param running_speed: The running_speed of this AssetResponse.  # noqa: E501
        :type: AssetRunningSpeedChild
        """

        self._running_speed = running_speed

    @property
    def criticality(self):
        """Gets the criticality of this AssetResponse.  # noqa: E501


        :return: The criticality of this AssetResponse.  # noqa: E501
        :rtype: AssetCriticalityChild
        """
        return self._criticality

    @criticality.setter
    def criticality(self, criticality):
        """Sets the criticality of this AssetResponse.


        :param criticality: The criticality of this AssetResponse.  # noqa: E501
        :type: AssetCriticalityChild
        """

        self._criticality = criticality

    @property
    def drum_roll(self):
        """Gets the drum_roll of this AssetResponse.  # noqa: E501


        :return: The drum_roll of this AssetResponse.  # noqa: E501
        :rtype: AssetDrumRollChild
        """
        return self._drum_roll

    @drum_roll.setter
    def drum_roll(self, drum_roll):
        """Sets the drum_roll of this AssetResponse.


        :param drum_roll: The drum_roll of this AssetResponse.  # noqa: E501
        :type: AssetDrumRollChild
        """

        self._drum_roll = drum_roll

    @property
    def hierarchy(self):
        """Gets the hierarchy of this AssetResponse.  # noqa: E501


        :return: The hierarchy of this AssetResponse.  # noqa: E501
        :rtype: list[HierarchyChild]
        """
        return self._hierarchy

    @hierarchy.setter
    def hierarchy(self, hierarchy):
        """Sets the hierarchy of this AssetResponse.


        :param hierarchy: The hierarchy of this AssetResponse.  # noqa: E501
        :type: list[HierarchyChild]
        """
        if hierarchy is None:
            raise ValueError("Invalid value for `hierarchy`, must not be `None`")  # noqa: E501

        self._hierarchy = hierarchy

    @property
    def parent(self):
        """Gets the parent of this AssetResponse.  # noqa: E501


        :return: The parent of this AssetResponse.  # noqa: E501
        :rtype: ParentChild
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this AssetResponse.


        :param parent: The parent of this AssetResponse.  # noqa: E501
        :type: ParentChild
        """
        if parent is None:
            raise ValueError("Invalid value for `parent`, must not be `None`")  # noqa: E501

        self._parent = parent

    @property
    def children(self):
        """Gets the children of this AssetResponse.  # noqa: E501


        :return: The children of this AssetResponse.  # noqa: E501
        :rtype: list[DescendantChild]
        """
        return self._children

    @children.setter
    def children(self, children):
        """Sets the children of this AssetResponse.


        :param children: The children of this AssetResponse.  # noqa: E501
        :type: list[DescendantChild]
        """
        if children is None:
            raise ValueError("Invalid value for `children`, must not be `None`")  # noqa: E501

        self._children = children

    @property
    def tags(self):
        """Gets the tags of this AssetResponse.  # noqa: E501


        :return: The tags of this AssetResponse.  # noqa: E501
        :rtype: list[AssetTagChild]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this AssetResponse.


        :param tags: The tags of this AssetResponse.  # noqa: E501
        :type: list[AssetTagChild]
        """
        if tags is None:
            raise ValueError("Invalid value for `tags`, must not be `None`")  # noqa: E501

        self._tags = tags

    @property
    def analytics_models(self):
        """Gets the analytics_models of this AssetResponse.  # noqa: E501


        :return: The analytics_models of this AssetResponse.  # noqa: E501
        :rtype: list[AssetAnalyticsModelChild]
        """
        return self._analytics_models

    @analytics_models.setter
    def analytics_models(self, analytics_models):
        """Sets the analytics_models of this AssetResponse.


        :param analytics_models: The analytics_models of this AssetResponse.  # noqa: E501
        :type: list[AssetAnalyticsModelChild]
        """
        if analytics_models is None:
            raise ValueError("Invalid value for `analytics_models`, must not be `None`")  # noqa: E501

        self._analytics_models = analytics_models

    @property
    def id(self):
        """Gets the id of this AssetResponse.  # noqa: E501


        :return: The id of this AssetResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AssetResponse.


        :param id: The id of this AssetResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this AssetResponse.  # noqa: E501


        :return: The name of this AssetResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AssetResponse.


        :param name: The name of this AssetResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def abbreviation(self):
        """Gets the abbreviation of this AssetResponse.  # noqa: E501


        :return: The abbreviation of this AssetResponse.  # noqa: E501
        :rtype: str
        """
        return self._abbreviation

    @abbreviation.setter
    def abbreviation(self, abbreviation):
        """Sets the abbreviation of this AssetResponse.


        :param abbreviation: The abbreviation of this AssetResponse.  # noqa: E501
        :type: str
        """
        if abbreviation is None:
            raise ValueError("Invalid value for `abbreviation`, must not be `None`")  # noqa: E501

        self._abbreviation = abbreviation

    @property
    def active(self):
        """Gets the active of this AssetResponse.  # noqa: E501


        :return: The active of this AssetResponse.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this AssetResponse.


        :param active: The active of this AssetResponse.  # noqa: E501
        :type: bool
        """
        if active is None:
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def is_paused(self):
        """Gets the is_paused of this AssetResponse.  # noqa: E501


        :return: The is_paused of this AssetResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_paused

    @is_paused.setter
    def is_paused(self, is_paused):
        """Sets the is_paused of this AssetResponse.


        :param is_paused: The is_paused of this AssetResponse.  # noqa: E501
        :type: bool
        """
        if is_paused is None:
            raise ValueError("Invalid value for `is_paused`, must not be `None`")  # noqa: E501

        self._is_paused = is_paused

    @property
    def is_snoozed(self):
        """Gets the is_snoozed of this AssetResponse.  # noqa: E501


        :return: The is_snoozed of this AssetResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_snoozed

    @is_snoozed.setter
    def is_snoozed(self, is_snoozed):
        """Sets the is_snoozed of this AssetResponse.


        :param is_snoozed: The is_snoozed of this AssetResponse.  # noqa: E501
        :type: bool
        """
        if is_snoozed is None:
            raise ValueError("Invalid value for `is_snoozed`, must not be `None`")  # noqa: E501

        self._is_snoozed = is_snoozed

    @property
    def created(self):
        """Gets the created of this AssetResponse.  # noqa: E501


        :return: The created of this AssetResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this AssetResponse.


        :param created: The created of this AssetResponse.  # noqa: E501
        :type: datetime
        """
        if created is None:
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    @property
    def corporation(self):
        """Gets the corporation of this AssetResponse.  # noqa: E501


        :return: The corporation of this AssetResponse.  # noqa: E501
        :rtype: CorporationChild
        """
        return self._corporation

    @corporation.setter
    def corporation(self, corporation):
        """Sets the corporation of this AssetResponse.


        :param corporation: The corporation of this AssetResponse.  # noqa: E501
        :type: CorporationChild
        """
        if corporation is None:
            raise ValueError("Invalid value for `corporation`, must not be `None`")  # noqa: E501

        self._corporation = corporation

    @property
    def location(self):
        """Gets the location of this AssetResponse.  # noqa: E501


        :return: The location of this AssetResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this AssetResponse.


        :param location: The location of this AssetResponse.  # noqa: E501
        :type: LocationChild
        """
        if location is None:
            raise ValueError("Invalid value for `location`, must not be `None`")  # noqa: E501

        self._location = location

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AssetResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GroupAlertsResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'indicator_id': 'str',
        'indicator_name': 'str',
        'indicator_sort_order': 'int',
        'hierarchy': 'list[HierarchyChild]',
        'time_of_alert': 'datetime',
        'external_notification': 'ExternalNotificationChild'
    }

    attribute_map = {
        'indicator_id': 'IndicatorId',
        'indicator_name': 'IndicatorName',
        'indicator_sort_order': 'IndicatorSortOrder',
        'hierarchy': 'Hierarchy',
        'time_of_alert': 'TimeOfAlert',
        'external_notification': 'ExternalNotification'
    }

    def __init__(self, indicator_id=None, indicator_name=None, indicator_sort_order=None, hierarchy=None, time_of_alert=None, external_notification=None):  # noqa: E501
        """GroupAlertsResponse - a model defined in Swagger"""  # noqa: E501
        self._indicator_id = None
        self._indicator_name = None
        self._indicator_sort_order = None
        self._hierarchy = None
        self._time_of_alert = None
        self._external_notification = None
        self.discriminator = None
        self.indicator_id = indicator_id
        self.indicator_name = indicator_name
        if indicator_sort_order is not None:
            self.indicator_sort_order = indicator_sort_order
        self.hierarchy = hierarchy
        if time_of_alert is not None:
            self.time_of_alert = time_of_alert
        if external_notification is not None:
            self.external_notification = external_notification

    @property
    def indicator_id(self):
        """Gets the indicator_id of this GroupAlertsResponse.  # noqa: E501


        :return: The indicator_id of this GroupAlertsResponse.  # noqa: E501
        :rtype: str
        """
        return self._indicator_id

    @indicator_id.setter
    def indicator_id(self, indicator_id):
        """Sets the indicator_id of this GroupAlertsResponse.


        :param indicator_id: The indicator_id of this GroupAlertsResponse.  # noqa: E501
        :type: str
        """
        if indicator_id is None:
            raise ValueError("Invalid value for `indicator_id`, must not be `None`")  # noqa: E501

        self._indicator_id = indicator_id

    @property
    def indicator_name(self):
        """Gets the indicator_name of this GroupAlertsResponse.  # noqa: E501


        :return: The indicator_name of this GroupAlertsResponse.  # noqa: E501
        :rtype: str
        """
        return self._indicator_name

    @indicator_name.setter
    def indicator_name(self, indicator_name):
        """Sets the indicator_name of this GroupAlertsResponse.


        :param indicator_name: The indicator_name of this GroupAlertsResponse.  # noqa: E501
        :type: str
        """
        if indicator_name is None:
            raise ValueError("Invalid value for `indicator_name`, must not be `None`")  # noqa: E501

        self._indicator_name = indicator_name

    @property
    def indicator_sort_order(self):
        """Gets the indicator_sort_order of this GroupAlertsResponse.  # noqa: E501


        :return: The indicator_sort_order of this GroupAlertsResponse.  # noqa: E501
        :rtype: int
        """
        return self._indicator_sort_order

    @indicator_sort_order.setter
    def indicator_sort_order(self, indicator_sort_order):
        """Sets the indicator_sort_order of this GroupAlertsResponse.


        :param indicator_sort_order: The indicator_sort_order of this GroupAlertsResponse.  # noqa: E501
        :type: int
        """

        self._indicator_sort_order = indicator_sort_order

    @property
    def hierarchy(self):
        """Gets the hierarchy of this GroupAlertsResponse.  # noqa: E501


        :return: The hierarchy of this GroupAlertsResponse.  # noqa: E501
        :rtype: list[HierarchyChild]
        """
        return self._hierarchy

    @hierarchy.setter
    def hierarchy(self, hierarchy):
        """Sets the hierarchy of this GroupAlertsResponse.


        :param hierarchy: The hierarchy of this GroupAlertsResponse.  # noqa: E501
        :type: list[HierarchyChild]
        """
        if hierarchy is None:
            raise ValueError("Invalid value for `hierarchy`, must not be `None`")  # noqa: E501

        self._hierarchy = hierarchy

    @property
    def time_of_alert(self):
        """Gets the time_of_alert of this GroupAlertsResponse.  # noqa: E501


        :return: The time_of_alert of this GroupAlertsResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_of_alert

    @time_of_alert.setter
    def time_of_alert(self, time_of_alert):
        """Sets the time_of_alert of this GroupAlertsResponse.


        :param time_of_alert: The time_of_alert of this GroupAlertsResponse.  # noqa: E501
        :type: datetime
        """

        self._time_of_alert = time_of_alert

    @property
    def external_notification(self):
        """Gets the external_notification of this GroupAlertsResponse.  # noqa: E501


        :return: The external_notification of this GroupAlertsResponse.  # noqa: E501
        :rtype: ExternalNotificationChild
        """
        return self._external_notification

    @external_notification.setter
    def external_notification(self, external_notification):
        """Sets the external_notification of this GroupAlertsResponse.


        :param external_notification: The external_notification of this GroupAlertsResponse.  # noqa: E501
        :type: ExternalNotificationChild
        """

        self._external_notification = external_notification

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GroupAlertsResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GroupAlertsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.indicator_groups_api import IndicatorGroupsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestIndicatorGroupsApi(unittest.TestCase):
    """IndicatorGroupsApi unit test stubs"""

    def setUp(self):
        self.api = IndicatorGroupsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_indicator_group(self):
        """Test case for create_indicator_group

        Creates a indicatorGroup  # noqa: E501
        """
        pass

    def test_delete_indicator_group(self):
        """Test case for delete_indicator_group

        Deletes a indicatorGroup  # noqa: E501
        """
        pass

    def test_get_indicator_group(self):
        """Test case for get_indicator_group

        Gets a indicatorGroup  # noqa: E501
        """
        pass

    def test_get_indicator_groups(self):
        """Test case for get_indicator_groups

        Gets indicatorGroups  # noqa: E501
        """
        pass

    def test_move_indicator_group(self):
        """Test case for move_indicator_group

        Moves a indicatorGroup  # noqa: E501
        """
        pass

    def test_update_indicator_group(self):
        """Test case for update_indicator_group

        Updates a indicatorGroup  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MetricTypeCodes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    TEMPERATURE = "Temperature"
    PRESSURE = "Pressure"
    FLOW = "Flow"
    HUMIDITY = "Humidity"
    POWER = "Power"
    DIFFERENTIALPRESSURE = "DifferentialPressure"
    VOLTAGE = "Voltage"
    GENERALIZEDATOD = "GeneralizedAtoD"
    VIBRATIONBANDRMS = "VibrationBandRms"
    VIBRATIONBANDMAX = "VibrationBandMax"
    VIBRATIONOVERALLPEAK = "VibrationOverallPeak"
    VIBRATIONOVERALLRMS = "VibrationOverallRms"
    VIBRATIONOVERALLSKEWNESS = "VibrationOverallSkewness"
    VIBRATIONOVERALLKURTOSIS = "VibrationOverallKurtosis"
    VIBRATIONOVERALLCRESTFACTOR = "VibrationOverallCrestFactor"
    DAMAGEACCUMULATION = "DamageAccumulation"
    VIBRATIONBANDRMSACCEL = "VibrationBandRmsAccel"
    VIBRATIONBANDMAXACCEL = "VibrationBandMaxAccel"
    VIBRATIONOVERALLPEAKACCEL = "VibrationOverallPeakAccel"
    VIBRATIONOVERALLRMSACCEL = "VibrationOverallRmsAccel"
    VIBRATIONOVERALLSKEWNESSACCEL = "VibrationOverallSkewnessAccel"
    VIBRATIONOVERALLKURTOSISACCEL = "VibrationOverallKurtosisAccel"
    VIBRATIONOVERALLCRESTFACTORACCEL = "VibrationOverallCrestFactorAccel"
    DAMAGEACCUMULATIONACCEL = "DamageAccumulationAccel"
    GROUP = "Group"
    VIBRATIONOVERALL = "VibrationOverall"
    VIBRATIONOVERALLACCEL = "VibrationOverallAccel"
    GENERALTIMESERIES = "GeneralTimeSeries"
    MATH = "Math"
    ONSTATISTICS = "OnStatistics"
    OFFSTATISTICS = "OffStatistics"
    ALARMSTATISTICS = "AlarmStatistics"
    WARNINGSTATISTICS = "WarningStatistics"
    POSITIVEPEAKPRESSURE = "PositivePeakPressure"
    NEGATIVEPEAKPRESSURE = "NegativePeakPressure"
    RMSPRESSURE = "RmsPressure"
    BANDPRESSURE = "BandPressure"
    ONPERCENTSTATISTICS = "OnPercentStatistics"
    OFFPERCENTSTATISTICS = "OffPercentStatistics"
    ALARMPERCENTSTATISTICS = "AlarmPercentStatistics"
    WARNINGPERCENTSTATISTICS = "WarningPercentStatistics"
    SIGNALSTRENGTH = "SignalStrength"
    RUNNINGSPEED = "RunningSpeed"
    DAMAGEACCUMULATIONPRESSURE = "DamageAccumulationPressure"
    OILHUMIDITY = "OilHumidity"
    OILTEMPERATURE = "OilTemperature"
    DAMAGEACCUMULATIONACCELRAW = "DamageAccumulationAccelRaw"
    THERMALREGIONOFINTEREST = "ThermalRegionOfInterest"
    SMARTMETRIC = "SmartMetric"
    FEATURE = "Feature"
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
    }

    attribute_map = {
    }

    def __init__(self):  # noqa: E501
        """MetricTypeCodes - a model defined in Swagger"""  # noqa: E501
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MetricTypeCodes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MetricTypeCodes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
